@@ -3,8 +3,7 @@
 *                          I C O   I n p u t / O u t p u t                      *
 *                                                                               *
 *********************************************************************************
-* Author: Janusz Ganczarski (POWER)   Email: JanuszG@enter.net.pl               *
-* Based on fxbmpio.cpp (FOX) and ico2xpm.c (Copyright (C) 1998 Philippe Martin) *
+* Copyright (C) 2001,2006 by Janusz Ganczarski.   All Rights Reserved.          *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -20,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxicoio.cpp,v 1.27.2.1 2005/12/15 22:52:37 fox Exp $                         *
+* $Id: fxicoio.cpp,v 1.33 2006/01/22 17:58:52 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -36,7 +35,6 @@
   - Partially transparent pixels are considered opaque, to prevent loss of
     data.
   - There is no OS/2 ICO format AFAIK.
-  - Need to have a pass, save as 32-bit when alpha present.
 */
 
 
@@ -51,44 +49,33 @@ using namespace FX;
 
 namespace FX {
 
-extern FXAPI FXbool fxcheckICO(FXStream& store);
-extern FXAPI FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot);
-extern FXAPI FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FXint xspot=-1,FXint yspot=-1);
+extern FXAPI bool fxcheckICO(FXStream& store);
+extern FXAPI bool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot);
+extern FXAPI bool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FXint xspot=-1,FXint yspot=-1);
 
 
 
-static inline FXuint read16(FXStream& store){
-  FXuchar c1,c2;
-  store >> c1 >> c2;
-  return ((FXuint)c1) | (((FXuint)c2)<<8);
-  }
-
-
-static inline FXuint read32(FXStream& store){
-  FXuchar c1,c2,c3,c4;
-  store >> c1 >> c2 >> c3 >> c4;
-  return ((FXuint)c1) | (((FXuint)c2)<<8) | (((FXuint)c3)<<16) | (((FXuint)c4)<<24);
-  }
-
-
 // Check if stream contains ICO
-FXbool fxcheckICO(FXStream& store){
+bool fxcheckICO(FXStream& store){
+  bool swap=store.swapBytes();
   FXshort signature[3];
-  signature[0]=read16(store);
-  signature[1]=read16(store);
-  signature[2]=read16(store);
+  store.setBigEndian(FALSE);
+  store.load(signature,3);
   store.position(-6,FXFromCurrent);
+  store.swapBytes(swap);
   return signature[0]==0 && (signature[1]==1 || signature[1]==2) && signature[2]>=1;
   }
 
 
 // Load ICO image from stream
-FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot){
-  FXlong   base,header;
+bool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot){
   FXColor  colormap[256],*pp;
+  FXlong   base,header;
   FXshort  idReserved;
   FXshort  idType;
   FXshort  idCount;
+  FXshort  wXHotspot;
+  FXshort  wYHotspot;
   FXuchar  bWidth;
   FXuchar  bHeight;
   FXuchar  bColorCount;
@@ -104,11 +91,13 @@ FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint
   FXint    biYPelsPerMeter;
   FXint    biClrUsed;
   FXint    biClrImportant;
-  FXshort  biPlanes;
   FXshort  biBitCount;
-  FXint    i,j,maxpixels,colormaplen,pad;
+  FXshort  biPlanes;
+  FXint    i,j,colormaplen,pad;
   FXuchar  c1;
   FXushort rgb16;
+  bool     swap;
+  bool     ok=FALSE;
 
   // Null out
   data=NULL;
@@ -120,30 +109,34 @@ FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint
   // Start of icon file header
   base=store.position();
 
-  // IconHeader
-  idReserved=read16(store);     // Must be 0
-  idType=read16(store);         // ICO=1, CUR=2
-  idCount=read16(store);        // Number of images
+  // Bitmaps are little-endian
+  swap=store.swapBytes();
+  store.setBigEndian(false);
 
-  FXTRACE((1,"fxloadICO: idReserved=%d idType=%d idCount=%d\n",idReserved,idType,idCount));
+  // IconHeader
+  store >> idReserved;     // Must be 0
+  store >> idType;         // ICO=1, CUR=2
+  store >> idCount;        // Number of images
+
+//  FXTRACE((1,"fxloadICO: idReserved=%d idType=%d idCount=%d\n",idReserved,idType,idCount));
 
   // Check
-  if(idReserved!=0 || (idType!=1 && idType!=2) || idCount<1) return FALSE;
+  if(idReserved!=0 || (idType!=1 && idType!=2) || idCount<1) goto x;
 
   // IconDirectoryEntry
   store >> bWidth;
   store >> bHeight;
   store >> bColorCount;
   store >> bReserved;
-  xspot = read16(store);
-  yspot = read16(store);
-  dwBytesInRes=read32(store);
-  dwImageOffset=read32(store);
+  store >> wXHotspot;
+  store >> wYHotspot;
+  store >> dwBytesInRes;
+  store >> dwImageOffset;
 
-  FXTRACE((1,"fxloadICO: bWidth=%d bHeight=%d bColorCount=%d bReserved=%d xspot=%d yspot=%d dwBytesInRes=%d dwImageOffset=%d\n",bWidth,bHeight,bColorCount,bReserved,xspot,yspot,dwBytesInRes,dwImageOffset));
+//  FXTRACE((1,"fxloadICO: bWidth=%d bHeight=%d bColorCount=%d bReserved=%d xspot=%d yspot=%d dwImageOffset=%d\n",bWidth,bHeight,bColorCount,bReserved,xspot,yspot,dwImageOffset));
 
   // Only certain color counts allowed; bColorCount=0 means 256 colors supposedly
-  if(bColorCount!=0 && bColorCount!=2 && bColorCount!=4 && bColorCount!=8 && bColorCount!=16) return FALSE;
+  if(bColorCount!=0 && bColorCount!=2 && bColorCount!=4 && bColorCount!=8 && bColorCount!=16) goto x;
 
   // Jump to BitmapInfoHeader
   store.position(base+dwImageOffset);
@@ -152,25 +145,25 @@ FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint
   header=store.position();
 
   // BitmapInfoHeader
-  biSize=read32(store);
-  biWidth=read32(store);
-  biHeight=read32(store)/2;     // Huh?
-  biPlanes=read16(store);
-  biBitCount=read16(store);
-  biCompression=read32(store);
-  biSizeImage=read32(store);
-  biXPelsPerMeter=read32(store);
-  biYPelsPerMeter=read32(store);
-  biClrUsed=read32(store);
-  biClrImportant=read32(store);
+  store >> biSize;
+  store >> biWidth;
+  store >> biHeight; biHeight/=2;   // Huh?
+  store >> biPlanes;
+  store >> biBitCount;
+  store >> biCompression;
+  store >> biSizeImage;
+  store >> biXPelsPerMeter;
+  store >> biYPelsPerMeter;
+  store >> biClrUsed;
+  store >> biClrImportant;
 
-  FXTRACE((1,"fxloadICO: biSize=%d biWidth=%d biHeight=%d biPlanes=%d biBitCount=%d biCompression=%d biSizeImage=%d biClrUsed=%d biClrImportant=%d\n",biSize,biWidth,biHeight,biPlanes,biBitCount,biCompression,biSizeImage,biClrUsed,biClrImportant));
+//  FXTRACE((1,"fxloadICO: biSize=%d biWidth=%d biHeight=%d biBitCount=%d biCompression=%d biClrUsed=%d\n",biSize,biWidth,biHeight,biBitCount,biCompression,biClrUsed));
 
   // Check for supported depths
-  if(biBitCount!=1 && biBitCount!=4 && biBitCount!=8 && biBitCount!=16 && biBitCount!=24 && biBitCount!=32) return FALSE;
+  if(biBitCount!=1 && biBitCount!=4 && biBitCount!=8 && biBitCount!=16 && biBitCount!=24 && biBitCount!=32) goto x;
 
   // Check for supported compression methods
-  if(biCompression!=BIH_RGB) return FALSE;
+  if(biCompression!=BIH_RGB) goto x;
 
   // Skip ahead to colormap
   store.position(header+biSize);
@@ -187,146 +180,117 @@ FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint
       }
     }
 
-  // Total number of pixels
-  maxpixels=biWidth*biHeight;
-
   // Allocate memory
-  if(!FXMALLOC(&data,FXColor,maxpixels)){ return FALSE; }
+  if(!FXMALLOC(&data,FXColor,biWidth*biHeight)) goto x;
 
   // Width and height
   width=biWidth;
   height=biHeight;
+  xspot=wXHotspot;
+  yspot=wYHotspot;
 
-  // 1-bit/pixel
-  if(biBitCount==1){
-    for(i=biHeight-1; i>=0; i--){
-      pp=data+i*biWidth;
-      for(j=0; j<biWidth; j++){
-        if((j&7)==0){ store >> c1; }
-        *pp++=colormap[(c1&0x80)>>7];
-        c1<<=1;
+  switch(biBitCount){
+    case 1:             // 1-bit/pixel
+      for(i=biHeight-1; i>=0; i--){
+        pp=data+i*biWidth;
+        for(j=0; j<biWidth; j++){
+          if((j&7)==0){ store >> c1; }
+          *pp++=colormap[(c1&0x80)>>7];
+          c1<<=1;
+          }
         }
-      }
-    }
-
-  // 4-bit/pixel
-  else if(biBitCount==4){
-    for(i=biHeight-1; i>=0; i--){
-      pp=data+i*biWidth;
-      for(j=0; j<biWidth; j++){
-        if((j&1)==0){ store >> c1; }
-        *pp++=colormap[(c1&0xf0)>>4];
-        c1<<=4;
+      break;
+    case 4:             // 4-bit/pixel
+      for(i=biHeight-1; i>=0; i--){
+        pp=data+i*biWidth;
+        for(j=0; j<biWidth; j++){
+          if((j&1)==0){ store >> c1; }
+          *pp++=colormap[(c1&0xf0)>>4];
+          c1<<=4;
+          }
         }
-      }
-    }
-
-  // 8-bit/pixel
-  else if(biBitCount==8){
-    for(i=biHeight-1; i>=0; i--){
-      pp=data+i*biWidth;
-      for(j=0; j<biWidth; j++){
-        store >> c1;
-        *pp++=colormap[c1];
+      break;
+    case 8:             // 8-bit/pixel
+      for(i=biHeight-1; i>=0; i--){
+        pp=data+i*biWidth;
+        for(j=0; j<biWidth; j++){
+          store >> c1;
+          *pp++=colormap[c1];
+          }
         }
-      }
-    }
-
-  // 16-bit/pixel
-  else if(biBitCount==16){
-    pad=(4-((biWidth*2)&3))&3;
-    for(i=biHeight-1; i>=0; i--){
-      pp=data+i*biWidth;
-      for(j=0; j<biWidth; j++){
-        rgb16=read16(store);
-        ((FXuchar*)pp)[0]=((rgb16>>7)&0xf8)+((rgb16>>12)&0x7);  // Red
-        ((FXuchar*)pp)[1]=((rgb16>>2)&0xf8)+((rgb16>> 7)&0x7);  // Green
-        ((FXuchar*)pp)[2]=((rgb16<<3)&0xf8)+((rgb16>> 2)&0x7);  // Blue
-        ((FXuchar*)pp)[3]=255;                                  // Alpha
-        pp++;
+      break;
+     case 16:           // 16-bit/pixel
+       pad=(4-((biWidth*2)&3))&3;
+       for(i=biHeight-1; i>=0; i--){
+         pp=data+i*biWidth;
+         for(j=0; j<biWidth; j++,pp++){
+           store >> rgb16;
+           ((FXuchar*)pp)[0]=((rgb16>>7)&0xf8)+((rgb16>>12)&0x7);  // Red
+           ((FXuchar*)pp)[1]=((rgb16>>2)&0xf8)+((rgb16>> 7)&0x7);  // Green
+           ((FXuchar*)pp)[2]=((rgb16<<3)&0xf8)+((rgb16>> 2)&0x7);  // Blue
+           ((FXuchar*)pp)[3]=255;                                  // Alpha
+           }
+         store.position(pad,FXFromCurrent);
+         }
+      break;
+    case 24:            // 24-bit/pixel
+      pad=(4-((biWidth*3)&3))&3;
+      for(i=biHeight-1; i>=0; i--){
+        pp=data+i*biWidth;
+        for(j=0; j<biWidth; j++,pp++){
+          store >> ((FXuchar*)pp)[2];             // Blue
+          store >> ((FXuchar*)pp)[1];             // Green
+          store >> ((FXuchar*)pp)[0];             // Red
+                   ((FXuchar*)pp)[3]=255;         // Alpha
+          }
+        store.position(pad,FXFromCurrent);
         }
-      store.position(pad,FXFromCurrent);
-      }
-    }
-
-  // 24-bit/pixel
-  else if(biBitCount==24){
-    pad=(4-((biWidth*3)&3))&3;
-    for(i=biHeight-1; i>=0; i--){
-      pp=data+i*biWidth;
-      for(j=0; j<biWidth; j++){
-        store >> ((FXuchar*)pp)[2];             // Blue
-        store >> ((FXuchar*)pp)[1];             // Green
-        store >> ((FXuchar*)pp)[0];             // Red
-        ((FXuchar*)pp)[3]=255;                  // Alpha
-        pp++;
+      break;
+    case 32:            // 32-bit/pixel
+      for(i=biHeight-1; i>=0; i--){
+        pp=data+i*biWidth;
+        for(j=0; j<biWidth; j++,pp++){
+          store >> ((FXuchar*)pp)[2];             // Blue
+          store >> ((FXuchar*)pp)[1];             // Green
+          store >> ((FXuchar*)pp)[0];             // Red
+          store >> ((FXuchar*)pp)[3];             // Alpha
+          }
         }
-      store.position(pad,FXFromCurrent);
-      }
-    }
-
-  // 32-bit/pixel
-  else{
-    for(i=biHeight-1; i>=0; i--){
-      pp=data+i*biWidth;
-      for(j=0; j<biWidth; j++){
-        store >> ((FXuchar*)pp)[2];     // Blue
-        store >> ((FXuchar*)pp)[1];     // Green
-        store >> ((FXuchar*)pp)[0];     // Red
-        store >> ((FXuchar*)pp)[3];     // Alpha
-        pp++;
-        }
-      }
+      break;
     }
 
   // Read 1-bit alpha data if no alpha channel, and skip otherwise.
   // We need to skip instead of just quit reading because the image
   // may be embedded in a larger stream and we need the byte-count to
   // remain correct for the format.
-  if(biBitCount==32){
-    store.position(store.position()+height*(width>>3));
-    }
-  else{
+  if(biBitCount!=32){
     pad=(4-((width+7)/8))&3;
     for(i=height-1; i>=0; i--){
       pp=data+i*width;
-      for(j=0; j<width; j++){
+      for(j=0; j<width; j++,pp++){
         if((j&7)==0){ store >> c1; }
         ((FXuchar*)pp)[3]=~-((c1&0x80)>>7);       // Groovy!
         c1<<=1;
-        pp++;
         }
       store.position(pad,FXFromCurrent);
       }
     }
+  else{
+    store.position(store.position()+height*(width>>3));
+    }
 
-  FXTRACE((1,"OK\n"));
-  return TRUE;
+  // Done
+  ok=true;
+x:store.swapBytes(swap);
+  return ok;
   }
 
+
 /*******************************************************************************/
 
 
-static inline void write16(FXStream& store,FXuint i){
-  FXuchar c1,c2;
-  c1=i&0xff;
-  c2=(i>>8)&0xff;
-  store << c1 << c2;
-  }
-
-
-static inline void write32(FXStream& store,FXuint i){
-  FXuchar c1,c2,c3,c4;
-  c1=i&0xff;
-  c2=(i>>8)&0xff;
-  c3=(i>>16)&0xff;
-  c4=(i>>24)&0xff;
-  store << c1 << c2 << c3 << c4;
-  }
-
-
 // Save a ICO file to a stream
-FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FXint xspot,FXint yspot){
+bool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FXint xspot,FXint yspot){
   const FXint    biSize=40;
   const FXshort  biPlanes=1;
   const FXint    biCompression=BIH_RGB;
@@ -343,15 +307,20 @@ FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FX
   const FXuchar  padding[3]={0,0,0};
   FXshort        biBitCount=24;
   FXshort        idType=2;
+  FXshort        wXHotspot=xspot;
+  FXshort        wYHotspot=yspot;
   FXint          biSizeImage=width*height*3;
   FXint          dwBytesInRes=biSize+biSizeImage+height*(width>>3);
+  FXint          iWidth=width;
+  FXint          iHeight=height+height;
   FXuchar        bWidth=(FXuchar)width;
   FXuchar        bHeight=(FXuchar)height;
   FXint          i,j,pad;
   FXuchar        c,bit;
+  bool           swap;
 
   // Must make sense
-  if(!data || width<=0 || height<=0) return FALSE;
+  if(!data || width<=0 || height<=0) return false;
 
   // Quick pass to see if alpha<255 anywhere
   for(i=width*height-1; i>=0; i--){
@@ -359,35 +328,42 @@ FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FX
     }
 
   // If no hot-spot given, save as an icon instead of a cursor
-  if(xspot<0 || yspot<0){ xspot=yspot=0; idType=1; }
+  if(wXHotspot<0 || wYHotspot<0){
+    wXHotspot=wYHotspot=0;
+    idType=1;
+    }
+
+  // Bitmaps are little-endian
+  swap=store.swapBytes();
+  store.setBigEndian(false);
 
   // IconHeader
-  write16(store,idReserved);    // Must be zero
-  write16(store,idType);        // Must be 1 or 2
-  write16(store,idCount);       // Only one icon
+  store << idReserved;          // Must be zero
+  store << idType;              // Must be 1 or 2
+  store << idCount;             // Only one icon
 
   // IconDirectoryEntry
   store << bWidth;
   store << bHeight;
   store << bColorCount;         // 0 for > 8bit/pixel
   store << bReserved;
-  write16(store,xspot);
-  write16(store,yspot);
-  write32(store,dwBytesInRes);  // Total number of bytes in images (including palette data)
-  write32(store,dwImageOffset); // Location of image from the beginning of file
+  store << wXHotspot;
+  store << wYHotspot;
+  store << dwBytesInRes;        // Total number of bytes in images (including palette data)
+  store << dwImageOffset;       // Location of image from the beginning of file
 
   // BitmapInfoHeader
-  write32(store,biSize);
-  write32(store,width);
-  write32(store,height+height);
-  write16(store,biPlanes);
-  write16(store,biBitCount);
-  write32(store,biCompression);
-  write32(store,biSizeImage);
-  write32(store,biXPelsPerMeter);
-  write32(store,biYPelsPerMeter);
-  write32(store,biClrUsed);
-  write32(store,biClrImportant);
+  store << biSize;
+  store << iWidth;
+  store << iHeight;
+  store << biPlanes;
+  store << biBitCount;
+  store << biCompression;
+  store << biSizeImage;
+  store << biXPelsPerMeter;
+  store << biYPelsPerMeter;
+  store << biClrUsed;
+  store << biClrImportant;
 
   // Write 24-bit rgb data
   if(biBitCount==24){
@@ -434,8 +410,8 @@ FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FX
       }
     }
   store.save(padding,pad);
-
-  return TRUE;
+  store.swapBytes(swap);
+  return true;
   }
 
 }
